/*
 * PSP Dialog Sample
 * Thomas Klein			tommydanger@aon.at
 *
 */

#include "../pspdialogs.h"

/* 
  basic setup for gu
  pspdlg doesn't provide a gu setup routine
  so you have to write/provide your own
  as every app needs a different setup
*/
#define BUF_WIDTH (512)
#define SCR_WIDTH (480)
#define SCR_HEIGHT (272)
#define PIXEL_SIZE (4)
#define FRAME_SIZE (BUF_WIDTH * SCR_HEIGHT * PIXEL_SIZE)
#define ZBUF_SIZE (BUF_WIDTH SCR_HEIGHT * 2)

unsigned int __attribute__((aligned(16))) list[262144];

/* Define the module info section */
PSP_MODULE_INFO("PSP Dialog Samples", 0, 1, 0);


/* Exit callback */
int exit_callback(int arg1, int arg2, void *common)
{
	sceKernelExitGame();
    return 0;
}

/* Callback thread */
int CallbackThread(SceSize args, void *argp)
{
    int cbid;
    cbid = sceKernelCreateCallback("Exit Callback", exit_callback, NULL);
    sceKernelRegisterExitCallback(cbid);
    sceKernelSleepThreadCB();

    return 0;
}

/* Sets up the callback thread and returns its thread id */
int SetupCallbacks(void)
{
    int thid = 0;
    thid = sceKernelCreateThread("update_thread", CallbackThread, 0x11, 0xFA0, 0, 0);
    if (thid >= 0)
	sceKernelStartThread(thid, 0, 0);
    return thid;
}

/* gu setup */
void SetupGu()
{
    sceGuInit();

    sceGuStart(GU_DIRECT,list);
    sceGuDrawBuffer(GU_PSM_8888,(void*)0,BUF_WIDTH);
    sceGuDispBuffer(SCR_WIDTH,SCR_HEIGHT,(void*)0x88000,BUF_WIDTH);
    sceGuDepthBuffer((void*)0x110000,BUF_WIDTH);
    sceGuOffset(2048 - (SCR_WIDTH/2),2048 - (SCR_HEIGHT/2));
    sceGuViewport(2048,2048,SCR_WIDTH,SCR_HEIGHT);
    sceGuDepthRange(0xc350,0x2710);
    sceGuScissor(0,0,SCR_WIDTH,SCR_HEIGHT);
    sceGuEnable(GU_SCISSOR_TEST);
    sceGuDepthFunc(GU_GEQUAL);
    sceGuEnable(GU_DEPTH_TEST);
    sceGuFrontFace(GU_CW);
    sceGuShadeModel(GU_SMOOTH);
    sceGuEnable(GU_CULL_FACE);
    sceGuEnable(GU_CLIP_PLANES);
    sceGuFinish();
    sceGuSync(0,0);
    
    sceDisplayWaitVblankStart();
    sceGuDisplay(GU_TRUE);
}

int main(int argc, char *argv[])
{
	SetupCallbacks();
	SetupGu();
    
	pspShowMessageDialog("PSP Dialogs Sample\nThis is a sample message box\n"
							"Next should be a message box in french",DIALOG_LANGUAGE_AUTO);
	
	pspShowMessageDialog("Now the message box controls should be displayed in french\n"
							"Next is a error dialog",PSP_SYSTEMPARAM_LANGUAGE_FRENCH);
	
	pspShowErrorDialog(0x80020001, DIALOG_LANGUAGE_AUTO);

	/* OSK */	
	unsigned short desc[] = {'O','S','K',' ','E','x','a','m','p','l','e',0};
	unsigned short pretext[] = {'p','s','p','d','l','g',' ','L','i','b','r','a','r','y',0};
	
	OSK_HELPER helper;
	memset(&helper,0,sizeof(OSK_HELPER));
	helper.title = (unsigned short*)desc;
	helper.pretext = (unsigned short*)pretext;
	helper.textlength = 256;
	helper.textlimit = 100;
	helper.lines = 1;

	pspShowOSK(&helper,DIALOG_LANGUAGE_AUTO);

	pspShowMessageDialog(helper.text,DIALOG_LANGUAGE_AUTO);

  	sceKernelExitGame();
  	return 0;
}
